#
# spec file for package xlockmore
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xlockmore
Version:        5.80
Release:        bp160.1.7
Summary:        Screen Saver and Locker for the X Window System
License:        MIT
Group:          System/X11/Utilities
URL:            https://sillycycle.com/xlockmore.html
Source:         https://sillycycle.com/xlock/%{name}-%{version}.tar.xz
Source1:        xlock.pamd
Source2:        xlock-wrapper
Source3:        xlock-wrapper_xorg6
Source4:        http://sillycycle.com/xlock/%{name}-%{version}.tar.xz.asc
Source5:        %{name}.keyring
# apply even patches when X.org < 7.0 else apply odd patches
Patch1:         %{name}-bitmaps.patch
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch3:         xlockmore-ttf_dir.patch
# end of X.org related patches
# PATCH-FIX-UPSTREAM xlockmore-extend-freetype-include-search.patch -- search only for freetype.h, not the half path. Also,
# extended list of directories where could freetype be found
Patch9:         xlockmore-extend-freetype-include-search.patch
Patch10:        xlockmore-nose_mode_crash.patch
Patch11:        xlockmore-cast-function-pointers.patch
BuildRequires:  ImageMagick-devel
BuildRequires:  automake
BuildRequires:  bc
BuildRequires:  fdupes
BuildRequires:  freeglut-devel
BuildRequires:  freetype2-devel
BuildRequires:  ftgl-devel
BuildRequires:  gcc-c++
BuildRequires:  libXdmcp-devel
BuildRequires:  libXinerama-devel
BuildRequires:  libXpm-devel
BuildRequires:  libXt-devel
BuildRequires:  libdrm-devel
BuildRequires:  pam-devel
BuildRequires:  pkgconfig

%description
The xlock utility locks your X Window System session and runs a screen
saver until a password is entered.

%define _xorg7libs %{_lib}
%define _xorg7libs32 lib
%define _xorg7bin bin
%define _xorg7_mandir %{_mandir}
%define _xorg7pixmaps include
%define _xorg7libshare lib
%define _xorg7_xkb %{_datadir}/X11/xkb
%define _xorg7_termcap %{_prefix}/lib/X11%{_sysconfdir}
%define _xorg7_serverincl %{_includedir}/xorg
%define _xorg7_fonts %{_datadir}/fonts
%define _xorg7_prefix %{_prefix}

%prep
%setup -q
chmod -x README docs/Revisions
%patch -P 1
%patch -P 3
%patch -P 9 -p1
%patch -P 10 -p1
%patch -P 11 -p1

%build
aclocal
autoconf
export CPPFLAGS="-I/usr/include/FTGL $(freetype-config --cflags)"
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
./configure \
	--prefix=%{_xorg7_prefix}\
	--with-libraries=%{_libdir}\
	--with-magick\
	--with-xinerama\
	--with-xpm\
	--without-gtk\
	--without-motif\
	--disable-bomb\
	--enable-pam\
	--enable-vtlock\
	--disable-allow-root\
	--x-includes=%{_xorg7_prefix}/include\
	--x-libraries=%{_xorg7_prefix}/%{_lib}
%make_build

%install
install -d -m 755 %{buildroot}%{_prefix}/%{_xorg7bin}/
install -d -m 755 %{buildroot}%{_prefix}/%{_xorg7libshare}/X11/app-defaults/
install -d -m 755 %{buildroot}%{_xorg7_mandir}/man1/
install -d -m 755 %{buildroot}%{_prefix}/%{_xorg7libs32}/xlock
install -m 755 xlock/xlock %{buildroot}%{_prefix}/%{_xorg7libs32}/xlock/xlock
install -m 644 xlock/XLock.ad %{buildroot}%{_prefix}/%{_xorg7libshare}/X11/app-defaults/XLock
install -m 644 xlock/xlock.man %{buildroot}%{_xorg7_mandir}/man1/xlock.1x
%if 0%{?suse_version} > 1500
install -d -m 755 %{buildroot}%{_pam_vendordir}
install -m 644 %{SOURCE1} %{buildroot}%{_pam_vendordir}/xlock
%else
install -d -m 755 %{buildroot}%{_sysconfdir}/pam.d
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/pam.d/xlock
%endif

%if "%(pkg-config --variable prefix x11 || echo %{_prefix}/X11R6)" == "%{_prefix}"
install -m 755 %{SOURCE2} %{buildroot}%{_prefix}/%{_xorg7bin}/xlock
%else
install -m 755 %{SOURCE3} %{buildroot}%{_prefix}/%{_xorg7bin}/xlock
%endif
%fdupes %{buildroot}%{_prefix}

%if 0%{?suse_version} > 1500
%pre
# Prepare for migration to /usr/lib; save any old .rpmsave
for i in pam.d/xlock ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i}.rpmsave.old ||:
done

%posttrans
# Migration to /usr/lib, restore just created .rpmsave
for i in pam.d/xlock ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i} ||:
done
%endif

%files
%doc %{_xorg7_mandir}/man1/xlock.1x.gz
%doc README docs/3d.howto docs/Purify docs/Revisions docs/TODO docs/cell_automata
%if 0%{?suse_version} > 1500
%{_pam_vendordir}/xlock
%else
%config %{_sysconfdir}/pam.d/xlock
%endif
%{_prefix}/%{_xorg7libshare}/X11/app-defaults
%{_prefix}/%{_xorg7bin}/xlock
%{_prefix}/%{_xorg7libs32}/xlock

%changelog
* Mon Sep 30 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 5.80:
  * pyraminx and oct mode extended now to any size > 1, also some hard
    coding of size removed and fixed some drawing errors.
* Sun Sep 15 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 5.79:
  * pyraminx and oct mode extended to size 6 also some hardcoding of size
    removed and fixed some drawing errors.
- Fix builds
  * Remove xlockmore-strict-aliasing.patch
  * Add xlockmore-cast-function-pointers.patch
* Tue Jun 11 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 5.78:
  * mball mode added simulating a Masterball puzzle.  The original has
    8 wedges and 4 bands, this version has 2 to 12 (even) wedges
    and usually 2 to 6 bands.
  * Fixed oct, pyraminx, bevel, dino, and skewb to show less silly
    moves, i.e. a move of a certain piece to the left and then to
    the right.
  * Added bean bags (rounded octahedrons) for juggler3d (like my own
    juggling balls).
  * A fix for random mode and in debug to show proper modes in list.
- 5.77 changelog:
  * Added period 2 edge turning to pyraminx.
  * pyraminx and oct mode extended to size 5 also some hardcoding of size
    removed.
* Wed Mar 27 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 5.76:
  * oct mode added.  Sizes 2-4.  Period 3 (face turning) and Period 4
    (corner turning) implemented also a "sticky" mode is implemented
    for both where the middle pieces turn together.
  * pyraminx code was reorganized and now scale the size of puzzle.
- 5.75 changelog:
  * pyraminx mode added.  Sizes 2-4.  With a "sticky" mode where its
    a size 4 but only certain turns are permitted.  So far only the
    normal Period 3 turning is permitted (i.e. faces or corners turn
    but not edges).  Taken from xpyraminx and dino and rubik modes.
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Jan  3 2024 ming li <mli@suse.com>
- Update to 5.74:
  * dino mode center fix (probably never see error).
  * bevel mode added.  Better known as the Helicopter Cube.  Currently,
    it only supports the 180 degree turns.  The ~71 degree turns would
    be very challenging to simulate.  Taken from an unreleased xbevel
    puzzle (which I am currently creating) and the skewb mode.
* Fri Oct  6 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 5.73:
  * dino mode added, mostly built from xdino and skewb mode.
  * fiberlamp mode fixed for multiscreen.
  * boxed mode report that it may be trapped in an infinite loop, I could
    not reproduce but added a hack so this will not happen.
- 5.72 changelog:
  * Update for OpenVMS for x86_64, small change to xshm.h and new make.com
    to work with clang and xmlock/xawlock thanks to Jouk Jansen. I hear
    its now possible to get a virtual OpenVMS on your Linux machine.
  * Update for xscreensaver-6.06 port to use grabclient instead of
    grabscreen.
  * configure now configures xmlock for Athena if you do not want Motif.
    Should work with most popular versions of Athena. You may want
    to change the name from xmlock to xawlock if you are using Athena.
    xawlock directory removed and was not meant to be distributed.
* Thu Jun 29 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 5.71:
  * Patch for Theobromine, Niacin, and Cobalamin from Richard Narron,
    richard AT aaazen.com.
  * Added cuboctahedron from mxico to ico mode.
  * xmlock updates for Athena for toggles.  Fix also for Xaw3d.  I think
    it has most of the working parts to the Motif version now.
- 5.70 changelog:
  * Patach for Cannabidiol and Fentanyl from Richard Narron, richard AT
    aaazen.com.
  * I was able to get DtScreen to work on Linux with CDE with slight
    modification to Makefile (documented in README) with help from Per
    Backman, 229pele AT tufftuff.net.
  * xmlock updates for Athena.  In generated Makefile will have to change
    HAVE_MOTIF to HAVE_ATHENA and change -lXm to -lXaw or -lXaw3d.  Just
    bare bones right now.
  * t3d.c: following recommendated change for configure "warning: Update your
    code to rely only on HAVE_SYS_TIME_H".  Also other assorted changes
    in configure.ac when I ran autoupdate (did not accept everything as
    it seemed to go wrong).
* Tue Jan  3 2023 Stefan Schubert <schubi@suse.com>
- Migration of PAM settings to /usr/lib/pam.d.
* Thu Dec 15 2022 Daniel Garcia <daniel.garcia@suse.com>
- Install resource files in /usr/lib/X11/app-defeaults/XLock instead of
  /usr/share.
  Fixes bsc#1204597
* Sun Mar 27 2022 Dirk Müller <dmueller@suse.com>
- update to 5.69:
  Patch for xkb groups thanks to Audrey Af, public.irkutsk AT gmail.com.
  Minor touches for xscreensaver-6.03 port, life and life3d.
* Tue Jan 25 2022 Avinesh Kumar <avinesh.kumar@suse.com>
- update to 5.68:
  * Updated xscreensaver port for xscreensaver-6.02.
  * Various NetBsd install issues fixed including config.cygport.
  * pam vulnerabiliy patch added thanks to Elmar Hoffmann, elho AT elho.net.
    Card vulnerability may remain, see README.
  * module fixes for deluxe, eyes, starfish, swirl, text3d2, module use is
    still experimental.
  * biof mode removed again (though was not building by default).
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 5.67:
  * Fixing specified bound equals destination size warning in iostuff.c.
  * Port updated for xscreensaver-6.01.  With help from EoflaOE ViceCity.
  * maze3d.c updated for VMS as CRTL now contains more standard functions
* Fri Nov 20 2020 Wang Jun <jgwang@suse.com>
- update to 5.66:
  GL mode atunnels, juggler3d, atlantis, lament, invert, solitaire, text3d,
    and text3d2 fixed up by EoflaOE ViceCity and myself to build in
    xscreensaver.
  bomb, helix, lightning, penrose, petal, scooter fixes for xscreensaver
    port (clear screen issue).  Clock fixed to run by changing a spot from
    "Clock" to "CLOCK".
  A few updates from xscreensaver-5.44/hacks/xlockmore.c for xscreensaver
    port.
  Duplicate resources and unloadable resources for xscreensaver port fixed
    by EoflaOE.
  Double free removed for xscreensaver port fixed by EoflaOE and myself.
  Removed some warnings in xscreensaver port in fzort, rubik, skewb, and
    sproingies.
  Xpm textures added to xscreensaver ports that need them.
  image, puzzle, decay, bat now work but use xscreensaver bitmap/pixmap
    in xscreensaver port.
  Bug fix in qix and toneclock for xscreensaver port, xlock was not
    affected by negative NRAND input.
  euler2d synced up with xscreensaver version.
  Change to fzort to use __asm__ instead of asm as its probably more
    likely to work.
  Fixed solitaire so deckPile changes just a little bit as it doles
    out cards.
  Updated bomb to use size 18 font when USE_MB is not set as it seems
    34 is not widely available anymore.
  pacman now has different colored ghosts (no green ghost) and also
    oscillating dress and eyes.  See README for a notice for this mode.
  Fixed some bad drawings in solitaire and pacman noticed on
    Windows side.
  Warnings removed for -Wstrict-prototypes -Wmissing-prototypes
  - Wdeclaration-after-statement
* Thu Sep 10 2020 Dirk Mueller <dmueller@suse.com>
- update to 5.65:
  Fix from Jan Kratochvil and Adrian Reber, adrian AT lisas.de for Fedora.
    xlock -startCmd true... would core on Fedora, exit() replaced with
    _exit().
  Update for magick.c to use strncpy thanks to Jouk Jansen.
  Fix for hyper mode from original author, for potential but not
    likely memory leak and free(NULL) issue John Heidemann, johnh
    AT isi.edu.
  More buffer gcc warnings removed for dclock.c, image.c, and
    scrnsave.c.
  ras.c/magick.c gcc 10 fix from Adrian Reber, adrian AT lisas.de .
    VMS already handles this in make.com.
  Lots of spelling errors fixed due to codespell
    https://manpages.debian.org/testing/codespell/codespell.1.en.html
  A few more gl modes (molecule, invert) fixed up by
    EoflaOE ViceCity to run in xscreensaver.
  Added additional changes to solitaire and invert.  invert will
    build in xscreensaver with some coaxing, see README in
    xscreensaver directory.
  Removed buffer gcc warning about nose.c.
  Fix from brett.diamond AT gmail.com to get "xlock -help" from
    crashing.
  As a Blake's 7 fan, I had to add the Liberator to star mode.
  Same fix from Jouk Jansen and Adrian Reber, adrian AT lisas.de
    for juggler3d.cc in previous release.
  Change from Denys Vlasenko (thanks to Adrian Reber for pointing out)
    https://bugzilla.redhat.com/show_bug.cgi?id=874484
    This helps xlock's parent process to know xlock crashed.
  ico mode added truncated octahedron.
  Another gl mode, sierpinski3d, fixed up by EoflaOE ViceCity to run
    in xscreensaver.
  Updated references to website to https.  https://www.sillycycle.com
  A few more gl modes (incl. maze3d, pipe, sproingies) fixed up by
    EoflaOE ViceCity to run in xscreensaver.
  Thanks to tobik, ohartmann AT walstatt.org, and Jason Helfman,
    jgh AT FreeBSD.org for xglock fixes for "failed due to signal" for
    clang.
  Syncing with xscreensaver and many modes modified, more than
    half working there.  pacman and puzzle run but need some
    obvious work, others run too fast or flash on the screen.
    Various fixes from Jouk Jansen and EoflaOE ViceCity.
    Updated GL modes also, inaddition to overlap: biof, skewb, and
    fire (needs images). See xscreensaver/README for new directions.
  Updated in linux to build with modules, must have broken somewhere
    down the line.  imake build fixed too.
  bomb mode fixed for xlock.
  Syncing with xscreensaver.  Much has changed since last time this
    was done and much left to do.  Nonglx "a"'s and some "b"'s done
    so far.  Automata modes like ant.c should use automata.c and
    automata.h supplied by xlockmore.
    ball bat not working right there yet.  Also bouboule to do right will
    require changes to xlockmore files from xscreensaver.
    See new xscreensaver/README for instructions.
  While testing uncovered old security bug in anenome mode and fixed.
  life updates to use a more standard notation for nontotalistic cellular
    automata.
  ax_pthread.m4 needed for autoconf, added back in, oops.
  Removed VMS caddr_t fix from matrix.c, cage.c, gears.c, glplanet.c,
    invert.c, juggler3d.c, lament.c, moebius.c, molecule.c, morph3d.c,
    noof.c, pipes.c, rubik.c, sierpinski3d.c, skewb.c, stairs.c,
    superquadrics.c as no longer needed.  Thanks to Jouk Jansen.
  boxed and maze3d modes added thanks mainly to Jouk Jansen.
  boxed added to xlock95.scr.  xlock95 Makefile now builds to 64 bit.
  Thanks to Jason Helfman, jgh AT FreeBSD.org for sound installation fixes.
  Thanks to Tobias Kortkamp, for his patch for glock compile issue with
    CLANG 6.0.0.
  Fixing warnings using clang for back.xpm, nose.c, passwd.c.
  Fixing errors using g++ for deluxe.c, also various casting added.
  Fixing potential some buffer overruns pointed out in mingw in
    apollonian.c and hyper.c.
  Fixing potential error of using null pointer thanks again to mingw in
    xlock.c.
  pyro2 was not showing anything on screen due to it not finding font,
    changed it to default to mode_font if can not find.
  Thanks to Dave Odell, dmo2118 AT gmail.com for his fzort mode update to
    use the functions in xshm.c and fixes crash when running X11 over network.
  Note from Dave Odell:
    <https://www.jwz.org/xscreensaver/xscreensaver-5.37.tar.gz>. MI_INIT() is
    defined and documented in hacks/xlockmore.h, with related functions
    defined in hacks/xlockmore.c.  MI_INIT() currently takes three parameters:
    the ModeInfo *, the state array, and a function pointer for the new free
    hook. FWIW, it could instead be just the first two parameters, with the
    free hook being set up like the other ModeHooks; this would be a bit
    nicer, I think. But I was going for something that could be applied
    incrementally to individual screenhacks in XScreenSaver, and could -- in
    theory -- be brought back to xlockmore with minimal impact.
  ant mode resync'd with xscreensaver...  Thanks to David Odell redoing my
    sad attempt.
  - sound configuration changed around so it should work on more machines,
    now uses DEF_PLAY and play.sh by default.
  Thanks to Stanislav Brabec, sbrabec AT suse.cz for his "hack" to fix for
    PAM with non-English locales.  He notes to fix properly a "Password"
    prompt list should be obtained at the initial phase of authentication.
    Added PAM_PASSWORD_PROMPT for using old way.
  Fixed leak in scooter thanks to Valgrind.
- remove xlockmore-pam.patch (upstream/obsolete)
* Mon Apr 23 2018 astieger@suse.com
- remove dependency on gpg-offline, part of source services now
* Tue Dec 12 2017 crrodriguez@opensuse.org
- Remove unused build require on gltt-devel, this allows to drop
  gltt and ancient freetype 1.x too.
* Wed May 31 2017 sbrabec@suse.com
- Update to version 5.54:
  * strange mode updates.
* Fri Apr 28 2017 sbrabec@suse.com
- Add a fix for double entering of password in non-English locales
  (boo#1035688, xlockmore-pam.patch).
* Wed Apr 26 2017 sbrabec@suse.com
- Update to version 5.53:
  * dclock fix for led bounce.
  * Install changes for fortune.
  * strange mode updates.
  * life3d updates.
  * messagefont fix.
  * Changed default message font.
  * spiral erase mode changed.
  * Fix for kumppa -speed 0.2.
  * new website at http://www.sillycycle.com
  * xmb fonts fix.
  * fixed xjack mode.
  * Updated language use.
- Refresh xlockmore-bitmaps.patch, xlockmore-ttf_dir.patch,
  xlockmore-extend-freetype-include-search.patch.
- Re-enable PAM (boo#1035688).
- Disable obsolete --enable-use-mb.
* Tue Mar 28 2017 lnussel@suse.de
- don't require pam-modules and unix2_chkpwd anymore. We use
  pam_unix noways which transparently manages access to /etc/shadow
* Wed Feb  8 2017 dimstar@opensuse.org
- Drop esound-devel BuildRequires: the distro moved away from
  esound some years ago.
- Drop xlockmore-no-copy-dt-needed-entries.patch: as esd is no
  longer being built, we also don't need to link it anymore.
* Tue Mar 10 2015 vcizek@suse.com
- fix a crash in nose mode (bnc#882747)
  * added xlockmore-nose_mode_crash.patch
* Tue Mar 10 2015 pgajdos@suse.com
- removed GPL-2.0+ from license string [bnc#734014]
* Wed Jan 28 2015 sbrabec@suse.cz
- Update to version 5.45:
  * Prevent pyro2 from X error.
  * Fix pentomino undefined behavior.
  * dilemma, voters, wator size fix for neighbors = 6.
  * Proper crediting for High Life part of life mode.
  * A few new gliders and patterns for life and life3d.
- Enable Xinerama support (bsc#911133), gltt, xpm and ImageMagick
  support.
* Mon Dec 16 2013 cougar@random.ee
- Added "pam-modules" dependency: xlockmore uses /sbin/unix2_chkpwd
  for password check. Without this binary it is not possible
  to unlock your X Window System session.
* Sun Dec 15 2013 hrvoje.senjan@gmail.com
- Added xlockmore-extend-freetype-include-search.patch: search only
  for freetype.h, not the half path. Also, extended list of
  directories where could freetype be found
- Pass $(freetype-config --cflags) to exported CPPFLAGS for potential
  future changes of freetype headers (as xlockmore uses hardcoded
  paths instead of a saner buildsystem)
* Thu Jul 18 2013 sbrabec@suse.cz
- Update to version 5.43:
  * many fixes and improvements, see Revisions for more.
  * Fix potential crash (CVE-2013-4143, bnc#829859)
- Remove ancient Provides/Obsoletes.
- Verify GPG signature.
* Mon Apr 22 2013 dimstar@opensuse.org
- Add libXdmcp-devel and libXt-devel BuildRequires: we include
  headers from the respective toolkits / libraries and as
  such it's only correct to BuildRequire the -devel package
  bringing these headers to us.
* Fri Feb  1 2013 coolo@suse.com
- update license to new format
* Thu Feb 23 2012 coolo@suse.com
- own app-defaults directory to fix build on factory
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Wed Nov 30 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Aug 30 2011 pgajdos@suse.com
- build with --no-copy-dt-needed-entries
  * no-copy-dt-needed-entries.patch
- updated to 5.34:
  * DPMS changed from 30 sec to 5 sec.  Define -DMIN_DPMS=3 at compile-time
    if you would like to change it to be sooner.
  * life mode fix for hexagons, life forms would not map certain screen sizes
  * life mode: Added new neighbor 9 ship, added asym ships for neighbor 12
    S356/B46, and added some new oscillators including a neighbor 6 p16.
    Now (mostly) use generated file from java app and life2d.xml.
  * life3d mode: Added new some new oscillators including a neighbor 12 p10
    S456/B3.  Also new puffers and gliders found.  Now use generated file
    from java app and life3d.xml.
  * loop mode: made new small loops less frequent
* Tue Dec 14 2010 coolo@novell.com
- update to 5.32
  * life3d update for -neighbors 14, new truncated octahedral life form.
  * ant & demon updates for -neighbors 5 or 7
  * -xinerama option added off by default.
  * skewb mode now scrambles, taken out of unstable category.
  * juggler3d mode stolen from xscreensaver with help from Tim Auckland.
  * petri: crashed due to shift of int, fix from Dr Nigel Warr
  * penrose should be working again.  Other small fixes for life, etc.
  * image: image set right away and added option -icononly to only display
    image when in password window
- remove support for outdated libraries and versions
* Tue Jul 28 2009 sbrabec@suse.cz
- Default to not accept root password to unlock (bnc#519637).
* Thu Jun 11 2009 sbrabec@suse.cz
- Updated to version 5.28:
  * Inrovements in modes: ant3d, life3d, life,
  * FTGL library support.
  * PAM_putText() fix.
  * configure checks for libXdpms
* Fri Nov 28 2008 sbrabec@suse.cz
- Do not install compile time pixmaps (bnc#450061).
* Wed Sep  3 2008 sbrabec@suse.cz
- Updated to version 5.26.1:
  * PAM_putText() would set pointer resp->resp to buffer.
  * "Esc" key now resets password entry.  Do not put an escape in
    your password.  This should behave the same as Control-U.
  * -showdate added.  +showdate allows you to turn off date in
    password window.
  * Inverted bitmap for xlock.
  * Updated the Java launcher in xlock.
  * antic cleanups.
  * New mode pyro2: -mode pyro2 -msg 'MSGSTR' -fnt 'FONT'
  * Modifications for +install, -mono.
  * New resource files for Chinese...
  * Automata modes now have triangular tilings drawn with a black
    triangle around it.
  * Fix for xlock -resource in life.c.
  * Added a compile-time option "-DNO_TIME if you dont want the
    time in the password window.
* Thu Jun  5 2008 pgajdos@suse.cz
- prevented against segfault when wrong locale selected [#90543]
  (null-fontset.patch)
* Tue Jun  3 2008 pgajdos@suse.cz
- removed mode text3d2 (xlockmore isn't linked against ftgl from
  now) [bnc#352683]
* Fri Apr 25 2008 sbrabec@suse.cz
- Updated to version 5.25:
  * ant3d, ant, life1d now with better colors.
  * rain a new mode from Frank Fesevur.
  * Fix for xlock -resource in life.c.
  * Added a compile-time option "-DNO_TIME if you dont want the
  time in the password window.
* Tue Aug  7 2007 sbrabec@suse.cz
- Updated to version 5.24:
  * penrose added to xlock95.
  * xcl added with a fix for DefaultScreen, which should not be
    there since xlock is a multiscreen program.
  * Patch for solitare and reducing binary size for xlock95.
  * dilemma, voters, wator hexagonal/triangular drawing
    improvements.
  * More triangular/hexagonal life.
  * Fixes for old options for command line -rule S2b34B2a and
  - rule S2a2b4aB2a3a4b using -neighbors 6.
  * Fixes for hexagonal diagonal shooters.
  * Added new hexagonal life -rule S35B2 and S3B245.
  * Added many new triangular life rules with gliders.
  * Updated random soup to include multiple symmetries.
  * Added options runtime -glidersearch and -patternsearch.
  * Added -repeat num option to help find patterns that do not
    repeat in num periods.
  * Added -vertical option to more modules.
  * DirectColor fixes for password window.
- Build with GLTT and FTGL modules.
* Wed Nov 15 2006 dmueller@suse.de
- build against freetype2, not freetype
* Mon Oct 23 2006 sbrabec@suse.cz
- Updated to version 5.23:
  * Bug fixes.
  * Several new options.
  * Memory leak fixes.
* Wed Sep 13 2006 sbrabec@suse.cz
- Adjusted BuildRequires for ftgl.
* Tue Sep  5 2006 lmichnovic@suse.cz
- fixed wrong path to the ttf fonts (ttf_dir*patch) [#153404]
- removed comments in xlockmore-bitmaps.patch
- file "xlock-wrapper_xorg6" created for use whith X.org <= 6.9
- fixed build with X.org <= 6.9; patches 2, 4 applies; the names
  ends with "xorg_6.patch"; patches 1, 3 applies if X.org >= 7.0
- fixed X libraries and headers path
* Wed Aug  9 2006 sndirsch@suse.de
- fixed paths in xlock wrapper script
* Wed Aug  2 2006 lmichnovic@suse.cz
- distinguishing prefix in X.org instead of suse_version
* Thu Jul 20 2006 lmichnovic@suse.cz
- fixed build for new X.org 7.x
* Tue Jun  6 2006 lmichnovic@suse.cz
- Update to version 5.22
  - fiberlamp fix for array bounds read and leak fix for deluxe
  - magick and raster file (ras) fixes for True Color by Jouk Jansen
  - Removed some compiler/lint warnings.
  - deluxe mode ported from xscreensaver by Jouk Jansen.
  - anemone mode ported from xscreensaver by Jouk Jansen
  - win32 changes from Petey Leinonen:
    added XPutPixel()
    pacman now works by changing the initialization and now can
    create a 1 bit depth bitmap when asked for.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 sbrabec@suse.cz
- Updated to version 5.21.
* Tue Nov 15 2005 uli@suse.de
- build with -O1 on ARM (ICE workaround)
* Thu Aug  4 2005 sbrabec@suse.cz
- Updated to version 5.18.
* Tue May 24 2005 mcihar@suse.cz
- update to 5.17
* Wed May 11 2005 mcihar@suse.cz
- update to 5.16
- dropped patch accepted by upstream
* Fri Mar 11 2005 mcihar@suse.cz
- fix reading resources (bug #72191)
* Tue Mar  8 2005 mcihar@suse.cz
- fix permissions
* Mon Feb 14 2005 mcihar@suse.cz
- update to 5.15
- more fontset support merged upstream
* Mon Dec  6 2004 mcihar@suse.cz
- update to 5.14.1
* Mon Nov 15 2004 kukuk@suse.de
- Use common-* PAM config files
* Tue Sep 14 2004 mcihar@suse.cz
- work correctly with utf-8 (bug #45065):
  - use multibyte X functions (--enable-use-mb)
  - calculate correctly font height for multibyte (xlockmore-fonts.patch)
  - use different fontset for signature (fixed) and messages (sans) (xlockmore-fonts.patch)
  - set default fonts to one available in SUSE (xlockmore-fonts.patch)
* Wed Aug  4 2004 mcihar@suse.cz
- update to 5.13
* Thu May 27 2004 mcihar@suse.cz
- update to 5.12
* Tue Apr 20 2004 mcihar@suse.cz
- enabled VT locking
* Tue Feb 24 2004 mcihar@suse.cz
- compile with -fno-strict-aliasing
- include more docs
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Wed Jan  7 2004 schwab@suse.de
- Don't hardcode SIGCHLD value.
- Fix quoting.
* Wed Jan  7 2004 mcihar@suse.cz
- updated to 5.11.1
- removed patches accepted by author
- do not trap SIGCHLD in wrapper script - bug #32858
* Thu Nov  6 2003 mcihar@suse.cz
- update to 5.10
* Wed Aug  6 2003 mcihar@suse.cz
- updated to 5.09
* Fri Jun 13 2003 kukuk@suse.de
- fix filelist
* Wed Apr 30 2003 mcihar@suse.cz
- renamed to xlockmore
- updated to 5.07.1:
  * Many buxfixes.
  * Checks for OpenGL errors.
  * Added a Caps Lock check.
* Fri Mar  7 2003 tcrhak@suse.cz
- restart xlock only when a signal was received,
  not when xlock ended with an error, e.g. unknown mode
* Mon Mar  3 2003 tcrhak@suse.cz
- Added xlock wrapper (source xlock-wrapper), replacing
  the original xlock. The wrapper restarts xlock whenever
  it terminates unexpectedly, e.g. when the used module
  segfaults. [bug #23091]
* Fri Feb  7 2003 kukuk@suse.de
- Use pam_unix2.so instead of pam_unix.so
* Tue Feb  4 2003 pmladek@suse.cz
- updated to version 5.06:
  * new mode petri
  * allow -erasemode to handle more complicated requests like
  - erasemode all-circle_wipe
  * and many bug fixes
- helper-bug.dif merged in helper.dif
* Mon Nov 18 2002 ro@suse.de
- removed duplication of AC_CONFIG_HEADER(config.h)
* Thu Sep 19 2002 pmladek@suse.cz
- previous change fixes the bugs #18790, #14329 and not the bug #18774
* Tue Sep  3 2002 pmladek@suse.cz
- fixed helper patch, FALLBACK_XLOCKRC is still not needed because PAM
  support is replaced by PASSWD_HELPER_PROGRAM [#18774]
* Tue Aug 27 2002 pmladek@suse.cz
- used --with-libraries=%%{_libdir} to fix for lib64
* Mon Aug 26 2002 pmladek@suse.cz
- pam module is accessed via new helper utility unix2_chkpw and xlock binary
  do not need group id bit now, many thanks to Olaf Kirch <okir@suse.de>
  for hint and patch [#18132]
* Mon Feb 18 2002 tcrhak@suse.cz
- fixed application default resources (XLock.*.bitmap); bug #13347
* Tue Feb 12 2002 cihlar@suse.cz
- removed sound support (it breaks Minimal+X11 selection)
* Tue Feb 12 2002 cihlar@suse.cz
- removed xlock-mesa due to problems with mesa
  screensavers [#12944]
* Tue Feb  5 2002 cihlar@suse.cz
- update to version 5.03
- added sound support (sound off by default)
- fixed to compile xlock without mesa and
  xlock-mesa with mesa
* Thu Nov  8 2001 ro@suse.de
- use mesa-devel-packages in neededforbuild
* Mon Oct 29 2001 dan@suse.cz
- update to 5.02 version
* Fri Aug 24 2001 schwab@suse.de
- Fix conflicting declaration.
* Tue Aug 14 2001 ro@suse.de
- Don't use absolute paths to PAM modules in PAM config files
* Thu Aug  9 2001 dan@suse.cz
- update to the latest stable (4.17.2)
* Mon Jun 25 2001 pblaha@suse.cz
- remove mode cartoon due to a copyright problems
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Thu Mar 15 2001 ro@suse.de
- changed neededforbuild <mesaglu> to <xf86glu>
- changed neededforbuild <mesaglu-devel> to <xf86glu-devel>
* Wed Mar  7 2001 ro@suse.de
- changed neededforbuild <mesadev> to <mesa-devel>
* Wed Feb  7 2001 uli@suse.de
- fixed for glibc 2.2.1
- removed cracklib, pam from neededforbuild
* Mon Jan 22 2001 schwab@suse.de
- Fix conflicting declarations.
- Add %%suse_update_config.
* Thu Aug 17 2000 smid@suse.cz
- format string security bug fixed
* Wed May 24 2000 smid@suse.cz
- mesadev added to needeforbuild
* Tue Apr 18 2000 smid@suse.cz
- buildroot added
- upgrade to 4.16
* Thu Mar 23 2000 ro@suse.de
- fixed to compile on both xf86
* Fri Jan  7 2000 kukuk@suse.de
- Update to 4.15
* Sat Oct 16 1999 kukuk@suse.de
- Build one version with and one without Mesa.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Jul  1 1999 kukuk@suse.de
- Link against Mesa
* Wed Jun 30 1999 kukuk@suse.de
- Don't give egid away, it's needed for reading shadow
* Mon Jun 28 1999 kukuk@suse.de
- update to 4.14
* Tue Jun  8 1999 kukuk@suse.de
- update 4.12 -> 4.13.1
- Compile with PAM
* Tue Jan 12 1999 uli@suse.de
- update 4.04 -> 4.12
* Tue Oct 14 1997 ro@suse.de
- updated file list
  ready for autobuild
* Fri Oct 10 1997 florian@suse.de
- update to version 4.04
* Sun Jun 22 1997 florian@suse.de
- update to version 4.02.1
* Wed Apr 30 1997 florian@suse.de
- make xlock sgid "shadow" and not suid "root"
* Sun Apr 27 1997 bs@suse.de
- update to new version 4.02 (security fix)
* Sun Apr 13 1997 florian@suse.de
- update to new version 4.01
- do not enable automatic logout button
* Sun Feb  2 1997 florian@suse.de
- update to new version 3.13
* Thu Jan  2 1997 florian@suse.de
- update from beta-version to official 3.12
* Thu Jan  2 1997 florian@suse.de
- update to newest version 3.12BETA due to security problems
* Thu Jan  2 1997 florian@suse.de
  update to new version 3.10
